@@ -1,9 +1,9 @@
 /* gc.h --- Header file for implementation agnostic crypto wrapper API.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2007  Simon Josefsson
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation; either version 2, or (at your
+ * by the Free Software Foundation; either version 3, or (at your
  * option) any later version.
  *
  * This file is distributed in the hope that it will be useful, but
@@ -45,7 +45,10 @@ enum Gc_hash
   GC_MD5,
   GC_SHA1,
   GC_MD2,
-  GC_RMD160
+  GC_RMD160,
+  GC_SHA256,
+  GC_SHA384,
+  GC_SHA512
 };
 typedef enum Gc_hash Gc_hash;
 
@@ -62,6 +65,9 @@ typedef void *gc_hash_handle;
 #define GC_MD5_DIGEST_SIZE 16
 #define GC_RMD160_DIGEST_SIZE 20
 #define GC_SHA1_DIGEST_SIZE 20
+#define GC_SHA256_DIGEST_SIZE 32
+#define GC_SHA384_DIGEST_SIZE 48
+#define GC_SHA512_DIGEST_SIZE 64
 
 /* Cipher types. */
 enum Gc_cipher
@@ -73,7 +79,9 @@ enum Gc_cipher
   GC_DES,
   GC_ARCFOUR128,
   GC_ARCFOUR40,
-  GC_ARCTWO40
+  GC_ARCTWO40,
+  GC_CAMELLIA128,
+  GC_CAMELLIA256
 };
 typedef enum Gc_cipher Gc_cipher;
 
